/*
 * helper_functions.cpp
 *
 *  Created on: Aug 23, 2017
 *      Author: julien
 */

#include "helper_functions.hpp"



void draw_pointcollection(Mat* src, vector<vector<Point>>* pointcollection){

	int pointcollectionsize = pointcollection->size();
	int subvector_size;

	for(signed int i = 0; i < pointcollectionsize; i++ ){
		Scalar color(0, i*150%255, 255);

		subvector_size = pointcollection->at(i).size();
		for(int j = 0; j < subvector_size; j++){
			circle(*src, pointcollection->at(i).at(j), 1, color, 2, 8, 0);
		}
	}
}

void draw_points(Mat* src, vector<Point>* points, Scalar color){

	for(int j = 0; j < points->size(); j++){
		circle(*src, points->at(j), 1, color, 2, 8, 0);
	}

}

void draw_points(Mat* src, vector<Point>* points_l, Scalar color_l,
				 vector<Point>* points_r, Scalar color_r){

	draw_points(src, points_l, color_l);
	draw_points(src, points_r, color_r);

}

void draw_lane_points(Mat* src, vector<vector<vector<Point>>>* contours){

	for(int contour = 0; contour < contours->size(); contour++){
		draw_pointcollection(src, &contours->at(contour));
	}
}

void print_mat_info(Mat a){
	cout << "Dims = " << a.dims << " Size = [";
	for(int i = 0; i < a.dims; ++i) {
		if(i) cout << " ; ";
		cout << a.size[i];
	}
	cout << "] Channels = " << a.channels() << endl;
}

void print_vector_vector(vector<vector<Point>> vec){
	for(unsigned int i = 0; i < vec.size(); i++){
		cout << vec[i] << endl;
	}
}


void print_mat(Mat M, String identifier){
	cout << identifier << " = "<< endl << " "  << M << endl << endl;
}


void to_pPointsVector(vector<vector<Point>>* src,
					  vector<vector<Function::pPoint>>* out){
	int size = src->size();

	*out = vector<vector<Function::pPoint>>(size);

	int src_sub_vector_size;

	vector<Function::pPoint>* out_sub_vector;
	vector<Point>* src_sub_vector;

	for(int i = 0; i < size; i++){

		src_sub_vector = &src->at(i);
		src_sub_vector_size = src_sub_vector->size();
		out_sub_vector = &out->at(i);

		*out_sub_vector = vector<Function::pPoint>(src_sub_vector_size);


		for(int j = 0; j < src_sub_vector_size; j++){
			out_sub_vector->at(j) = Function::pPoint(src_sub_vector->at(j));
		}
	}
}

void to_pPoints(vector<Point>* src, vector<Function::pPoint>* out){

	int size = src->size();

	*out = vector<Function::pPoint>(size);

	for(int j = 0; j < size; j++){
		out->at(j) = Function::pPoint(src->at(j));
	}
}

void to_pPoints(vector<Point>* src_l, vector<Function::pPoint>* out_l,
				vector<Point>* src_r, vector<Function::pPoint>* out_r){

	to_pPoints(src_l, out_l);
	to_pPoints(src_r, out_r);
}


void to_PointsVector(vector<vector<Function::pPoint>>* src, vector<vector<Point>>* out){
	int size = src->size();

	*out = vector<vector<Point>>(size);

	int src_sub_vector_size;

	vector<Function::pPoint>* src_sub_vector;
	vector<Point>* out_sub_vector;


	for(int i = 0; i < size; i++){

		src_sub_vector = &src->at(i);
		src_sub_vector_size = src_sub_vector->size();
		out_sub_vector = &out->at(i);

		*out_sub_vector = vector<Point>(src_sub_vector_size);


		for(int j = 0; j < src_sub_vector_size; j++){
			out_sub_vector->at(j) = Point(src_sub_vector->at(j).x,
										  src_sub_vector->at(j).y);
		}
	}
}

void to_Points(vector<Function::pPoint>* src, vector<Point>* out){

	int size = src->size();

	*out = vector<Point>(size);

	for(int j = 0; j < size; j++){
		out->at(j) = Point(src->at(j).x, src->at(j).y);
	}
}

void to_Points(vector<Function::pPoint>* src_l, vector<Point>* out_l,
			   vector<Function::pPoint>* src_r, vector<Point>* out_r){

	to_Points(src_l, out_l);
	to_Points(src_r, out_r);
}
